@@ -19,21 +19,23 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2008 PgPool Global Development Group
- * @version    CVS: $Id: innerSummary.php,v 1.3 2008/02/01 07:06:40 yamaguti Exp $
+ * @copyright  2003-2011 PgPool Global Development Group
+ * @version    CVS: $Id: innerSummary.php,v 1.6 2011/10/13 03:02:22 anzai Exp $
  */
 
 require_once('common.php');
 
-if(!isset($_SESSION[SESSION_LOGIN_USER])) {
+if (!isset($_SESSION[SESSION_LOGIN_USER])) {
     exit();
 }
 
 $params = readConfigParams(array('parallel_mode',
-                                              'enable_query_cache',
-                                              'replication_mode',
-                                              'load_balance_mode',
-                                              'health_check_period'));
+                                 'master_slave_mode',
+                                 'master_slave_sub_mode',
+                                 'enable_query_cache',
+                                 'replication_mode',
+                                 'load_balance_mode',
+                                 'health_check_period'));
 
 $tpl->assign('params', $params);
 $tpl->display('innerSummary.tpl');
